@@ -2,7 +2,7 @@ package Params::CallbackRequest::Exceptions;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '1.18';
+$VERSION = '1.19';
 
 use Exception::Class (
     'Params::Callback::Exception' => {
@@ -222,6 +222,15 @@ L<Params::CallbackRequest|Params::CallbackRequest> sets up callbacks for executi
 L<Exception::Class|Exception::Class> defines the interface for the exception
 classes created here.
 
+=head1 SUPPORT
+
+This module is stored in an open repository at the following address:
+
+L<https://svn.kineticode.com/Params-CallbackRequest/trunk/>
+
+Patches against Params::CallbackRequest are welcome. Please send bug reports
+to <bug-params-callbackrequest@rt.cpan.org>.
+
 =head1 AUTHOR
 
 David Wheeler <david@kineticode.com>
